@@ -1,2 +1,3 @@
 from .video_writer import VideoWriter, CV2VideoWriter
-from .video_capture import VideoCapture
+
+__all__ = ["VideoWriter"]
\ No newline at end of file
